Namespace VisualBasicLernen.MetricsConverter
   Public Class Temperature
      ' Der absolute Nullpunkt in den drei Maeinheiten
      Private Const absZeroFahrenheit As Double = -459.67
      Private Const absZeroKelvin As Double = 0
      Private Const absZeroCelsius As Double = -273.15

      ''' <summary>
      ''' Wandelt bergebene Celsius.Temperatur in Fahrenheit um.
      ''' </summary>
      ''' <param name="celsius">Temperatur in Celsius</param>
      ''' <returns>Temperatur in Fahrenheit</returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Celsius ist -273,15. 
      ''' </exception>
      Public Shared Function CelsiusToFahrenheit(ByVal celsius As Double) As Double
         ' Prfen, ob Parameter im zulssigen Wertebereich
         ' wenn nicht, Ausnahme auslsen
         If (celsius < absZeroCelsius) Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return (celsius * 9 / 5 + 32)
      End Function


      '''<summary>
      '''Konvertiert eine Temperatur von Celsius nach Kelvin
      '''/ </summary>
      ''' <param name="celsius">Temperatur in Celsius</param>
      ''' <returns>Temperatur in Kelvin</returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Celsius ist -273,15. 
      ''' </exception>
      Public Shared Function CelsiusToKelvin(ByVal celsius As Double) As Double
         'Prfen, ob Parameter im zulssigen Wertebereich
         ' wenn nicht, Ausnahme auslsen
         If celsius < absZeroCelsius Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return (celsius + Math.Abs(absZeroCelsius))
      End Function





      '''<summary>
      '''Konvertiert eine Temperatur von Fahrenheit nach Celsius 
      '''/ </summary>
      ''' <param name="fahrenheit">Temperatur in Fahrenheit</param>
      ''' <returns>Temperatur in Celsius </returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Fahrenheit ist -459.67. 
      ''' </exception>
      Public Shared Function FahrenheitToCelsius(ByVal fahrenheit As Double) As Double
         ' Prfen, ob Parameter im zulssigen Wertebereich
         ' nicht, Ausnahme auslsen
         If fahrenheit < absZeroFahrenheit Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return ((fahrenheit - 32) / 1.8)
      End Function

      '''<summary>
      '''Konvertiert eine Temperatur von Fahrenheit nach Kelvin 
      '''/ </summary>
      ''' <param name="fahrenheit">Temperatur in Fahrenheit</param>
      ''' <returns>Temperatur in Kelvin</returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Fahrenheit ist -459.67. 
      ''' </exception>
      Public Shared Function FahrenheitToKelvin(ByVal fahrenheit As Double) As Double
         ' Prfen, ob Parameter im zulssigen Wertebereich
         ' nicht, Ausnahme auslsen
         If (fahrenheit < absZeroFahrenheit) Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return ((fahrenheit + Math.Abs(absZeroFahrenheit)) / 1.8)
      End Function
      '''<summary>
      '''Konvertiert eine Temperatur von Kelvin nach Fahrenheit 
      '''/ </summary>
      ''' <param name="kelvin">Temperatur in Kelvin</param>
      ''' <returns>Temperatur in Fahrenheit </returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Kelvin ist 0. 
      ''' </exception>
      Public Shared Function KelvinToFahrenheit(ByVal kelvin As Double) As Double
         ' Prfen, ob Parameter im zulssigen Wertebereich
         ' wenn nicht, Ausnahme auslsen
         If kelvin < absZeroKelvin Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return ((kelvin * 1.8) - Math.Abs(absZeroFahrenheit))
      End Function
      '''<summary>
      '''Konvertiert eine Temperatur von Kelvin nach Celsius
      '''/ </summary>
      ''' <param name="kelvin">Temperatur in Kelvin</param>
      ''' <returns>Temperatur in Celsius</returns>
      ''' <exception cref="System.ArgumentOutOfRangeException">
      ''' Der absolute Nullpunkt in Kelvin ist 0. 
      ''' </exception>
      Public Shared Function KelvinToCelsius(ByVal kelvin As Double) As Double
         '  Prfen, ob Parameter im zulssigen Wertebereich
         ' wenn nicht, Ausnahme auslsen
         If (kelvin < absZeroKelvin) Then
            Throw New System.ArgumentOutOfRangeException()
         End If

         ' Temperatur konvertieren
         Return (kelvin - Math.Abs(absZeroCelsius))
      End Function



      ''' <summary>
      ''' ReadOnly-Property fr den kleinsten mglichen Kelvin-Wert.
      ''' </summary>
      Public Shared ReadOnly Property MinValueKelvin() As Double
         Get
            Return absZeroKelvin
         End Get
      End Property
      '''<summary>
      ''' ReadOnly-Property fr den kleinsten mglichen Fahrenheit-Wert.
      ''' </summary>
      Public Shared ReadOnly Property MinValueFahrenheit() As Double
         Get
            Return absZeroFahrenheit
         End Get
      End Property
      '''<summary>
      ''' ReadOnly-Property fr den kleinsten mglichen Celsius-Wert.
      ''' </summary>
      Public Shared ReadOnly Property MinValueCelsius() As Double
         Get
            Return absZeroCelsius
         End Get
      End Property

   End Class
End Namespace
