Public Enum LoggingLevel As Byte
   Low = 5
   Medium = 10
   High
End Enum
Public Class Logger
   ''' <summary>
   ''' Liest/setzt das Protokoll-Level.
   ''' </summary>
   Public Property LogLevel As LoggingLevel

   ' Name der Protokolldatei
   Private mLogFile As String

   ''' <summary>
   ''' Standardkonstruktor, legt den Dateinamen und das Protokoll-Level
   ''' nach den Standardkonventionen der Klasse fest
   ''' </summary>
   Public Sub New()
      ' Standardwert fr Protokoll-Level festlegen
      Me.LogLevel = LoggingLevel.High

      ' Der Pfadname der LogDatei wird mit einem StringBuilder-
      ' Objekt zusammengebaut
      Dim sb As New System.Text.StringBuilder
      With sb
         ' Pfad der ausgefhrten Anwendung holen 
         .Append(My.Application.Info.DirectoryPath)
         ' Slash anhngen
         .Append("\")
         ' Datum im Kurzformat anhngen
         .Append(DateTime.Now.ToShortDateString())
         'Unterstrich anhngen
         .Append("_")
         ' Namen der exe-Datei ermitteln und anhngen
         .Append(My.Application.Info.AssemblyName)
         ' Erweiterung .log anhngen
         .Append(".log")
         mLogFile = .ToString()
      End With

   End Sub
   ''' <summary>
   ''' Konstruktor, mit dem Pfad/Name der Protokolldatei festgelegt werden kann.
   ''' </summary>
   ''' <param name="logFile">Kompletter Pfadname der Protokolldatei.</param>
   Public Sub New(ByVal logFile As String)
      ' Standardwert fr Protokoll-Level festlegen
      Me.LogLevel = LoggingLevel.High
      ' Dateinamen so eintragen, wie er an den Konstruktor bergeben wird
      mLogFile = logFile
   End Sub
   ''' <summary>
   ''' Konstruktor, mit dem sowohl Pfad/Name der Protokolldatei 
   ''' als auch das Protokoll-Level festgelegt werden kann.
   ''' </summary>
   ''' <param name="logFile">Kompletter Pfadname der Protokolldatei</param>
   ''' <param name="logLevel">gewnschtes Protokoll-Level</param>
   ''' <remarks></remarks>
   Public Sub New(ByVal logFile As String, ByVal logLevel As LoggingLevel)
      ' bergebenen Protokoll-Level eintragen
      Me.LogLevel = logLevel
      ' Dateinamen so eintragen, wie er an den Konstruktor bergeben wird
      mLogFile = logFile
   End Sub
   ''' <summary>
   ''' Schreibt Informationen ber eine Ausnahme in die Protokolldatei
   ''' </summary>
   ''' <param name="exc">Ausnahme, die protokolliert werden soll</param>
   ''' <remarks></remarks>
   Public Sub DoLog(ByVal exc As Exception)

      Dim sb As New System.Text.StringBuilder()
      With sb
         ' Datum und Uhrzeit eintragen, mit Zeilenwechsel abschlieen
         .Append(DateTime.Now.ToShortDateString())
         .Append(" - ")
         .Append(DateTime.Now.ToLongTimeString())
         .Append(System.Environment.NewLine)
         ' Informationen ber Ausnahme holen, mit Zeilenwechsel abschlieen
         .Append(getExceptionData(exc, Me.LogLevel))
         .Append(System.Environment.NewLine)
      End With

      Try
         ' Protokolldaten in Datei schreiben 
         My.Computer.FileSystem.WriteAllText(mLogFile, sb.ToString(), True)
      Catch ex As Exception

      End Try

   End Sub

   Private Function getExceptionData(ByVal exc As Exception, ByVal logLevel As LoggingLevel) As String
      Dim sb As New System.Text.StringBuilder()

      With sb
         Select Case logLevel
            Case LoggingLevel.Low
               .Append("Message: ")
               .Append(exc.Message)
               .Append(System.Environment.NewLine)

            Case LoggingLevel.Medium
               .Append("Message: ")
               .Append(exc.Message)
               .Append(System.Environment.NewLine)
               If Not IsNothing(exc.Source) Then
                  .Append("Source: ")
                  .Append(exc.Source)
                  .Append(System.Environment.NewLine)
               End If
               If Not IsNothing(exc.TargetSite) Then
                  .Append("TargetSite: ")
                  .Append(exc.TargetSite)
                  .Append(System.Environment.NewLine)
               End If

            Case LoggingLevel.High
               .Append("Message: ")
               .Append(exc.Message)
               .Append(System.Environment.NewLine)
               If Not IsNothing(exc.Source) Then
                  .Append("Source: ")
                  .Append(exc.Source)
                  .Append(System.Environment.NewLine)
               End If

               If Not IsNothing(exc.TargetSite) Then
                  .Append("TargetSite: ")
                  .Append(exc.TargetSite)
                  .Append(System.Environment.NewLine)
               End If
               If Not IsNothing(exc.TargetSite) Then
                  .Append("StackTrace: ")
                  .Append(exc.StackTrace)
                  .Append(System.Environment.NewLine)
               End If

         End Select
      End With
      Return sb.ToString()
   End Function
   ''' <summary>
   ''' Schreibt eine Textmeldung in die Protokolldatei.
   ''' </summary>
   ''' <param name="msg">Meldung, die geschrieben werden soll.</param>
   ''' <remarks></remarks>
   Public Sub DoLog(ByVal msg As String)
      Dim sb As New System.Text.StringBuilder()
      With sb
         ' Datum und Uhrzeit eintragen, mit Zeilenwechsel abschlieen
         .Append(DateTime.Now.ToShortDateString())
         .Append(" - ")
         .Append(DateTime.Now.ToLongTimeString())
         .Append(System.Environment.NewLine)
         ' Gewnschten Text einfgen, mit Zeilenwechsel abschlieen
         .Append(msg)
         .Append(System.Environment.NewLine)
      End With

      Try
         ' Protokolldaten in Datei schreiben 
         My.Computer.FileSystem.WriteAllText(mLogFile, sb.ToString(), True)
      Catch ex As Exception

      End Try

   End Sub
   ''' <summary>
   ''' Ruft den aktuellen Namen der Protokolldatei ab (schreibgeschtzt).
   ''' </summary>
   Public ReadOnly Property LogFile() As String
      Get
         Return mLogFile
      End Get
   End Property


End Class
